@@ -385,6 +385,25 @@ on_button_press (GooCanvasItem *item,
 }
 
 
+static gboolean
+on_scroll (GooCanvasItem *item,
+	   GooCanvasItem *target,
+	   GdkEventScroll *event,
+	   gpointer data)
+{
+#if 0
+  g_print ("received 'scroll-event' signal\n");
+#endif
+
+  if (event->direction == GDK_SCROLL_UP)
+    goo_canvas_item_scale (item, 1.1, 1.1);
+  else if (event->direction == GDK_SCROLL_DOWN)
+    goo_canvas_item_scale (item, 0.909, 0.909);
+  else return FALSE;
+
+  return TRUE;
+}
+
 static gboolean
 on_button_release (GooCanvasItem *item,
 		   GooCanvasItem *target,
@@ -404,7 +423,6 @@ on_button_release (GooCanvasItem *item,
   return TRUE;
 }
 
-
 static gboolean
 on_background_button_press (GooCanvasItem *item,
 			    GooCanvasItem *target,
@@ -473,6 +491,7 @@ create_canvas_primitives ()
 		      "bounds-from-origin", FALSE,
 		      "bounds-padding", 4.0,
 		      "background-color-rgb", 0xC3C3FF,
+ 		      "has-tooltip", TRUE,
 #if 0
 		      "redraw-when-scrolled", TRUE,
 #endif
@@ -834,6 +853,7 @@ setup_rectangles (GooCanvasItem *root)
   item = goo_canvas_rect_new (root, 20, 30, 50, 30,
 			      "stroke-color", "red",
 			      "line-width", 8.0,
+			      "tooltip", "Red stroked rectangle",
 			      NULL);
   setup_item_signals (item);
 
@@ -842,6 +862,7 @@ setup_rectangles (GooCanvasItem *root)
 			      "fill-pattern", pattern,
 			      "stroke-color", "black",
 			      "line-width", 4.0,
+			      "tooltip", "Medium Sea Green stippled rectangle",
 			      NULL);
   cairo_pattern_destroy (pattern);
   setup_item_signals (item);
@@ -849,6 +870,7 @@ setup_rectangles (GooCanvasItem *root)
   item = goo_canvas_rect_new (root, 10, 80, 70, 60,
 			      "fill-color", "steelblue",
 			      /*"fill-pattern", NULL,*/
+			      "tooltip", "Steel Blue rectangle",
 			      NULL);
   setup_item_signals (item);
 
@@ -856,6 +878,7 @@ setup_rectangles (GooCanvasItem *root)
 			      "fill-color-rgba", 0x3cb37180,
 			      "stroke-color", "blue",
 			      "line-width", 2.0,
+			      "tooltip", "Partially transparent rectangle",
 			      NULL);
   setup_item_signals (item);
 
@@ -864,11 +887,13 @@ setup_rectangles (GooCanvasItem *root)
 			      "radius-y", 10.0,
 			      "stroke-color", "yellow",
 			      "fill-color-rgba", 0x3cb3f180,
+			      "tooltip", "Rectangle with rounded corners",
 			      NULL);
   setup_item_signals (item);
 
   item = goo_demo_item_new (root, 30, 20, 50, 30,
 			    "fill-color", "yellow",
+			    "tooltip", "Yellow demo item",
 			    NULL);
   setup_item_signals (item);
 }
@@ -1098,6 +1123,7 @@ setup_polygons (GooCanvasItem *root)
   cairo_pattern_destroy (pattern);
   goo_canvas_points_unref (points);
   setup_item_signals (polyline1);
+  
 
   points = goo_canvas_points_new (14);
   points->coords[0] = 270.0;
@@ -1158,6 +1184,9 @@ make_anchor (GooCanvasItem *root, double x, double y)
 			      NULL);
   setup_item_signals (item);
 
+  g_signal_connect (group, "scroll_event",
+		    G_CALLBACK (on_scroll), NULL);
+
   return group;
 }
 
