@@ -303,7 +303,7 @@ on_button_press (GooCanvasItem *item,
 	  fleur = gdk_cursor_new (GDK_FLEUR);
 	  canvas = goo_canvas_item_get_canvas (item);
 	  goo_canvas_pointer_grab (canvas, item,
-				   GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK,
+				   GDK_POINTER_MOTION_MASK | GDK_POINTER_MOTION_HINT_MASK | GDK_BUTTON_RELEASE_MASK,
 				   fleur,
 				   event->time);
 	  gdk_cursor_unref (fleur);
@@ -385,7 +385,8 @@ on_item_created (GooCanvas          *canvas,
 
 
 GtkWidget *
-create_canvas_primitives (GooCanvasItemModel *model)
+create_canvas_primitives (GooCanvasItemModel *model,
+			  GooCanvasItemModel *static_model)
 {
 	GtkWidget *vbox;
 	GtkWidget *hbox;
@@ -414,6 +415,10 @@ create_canvas_primitives (GooCanvasItemModel *model)
 		      "bounds-from-origin", FALSE,
 		      "bounds-padding", 4.0,
 		      "background-color-rgb", 0xC3C3FF,
+ 		      "has-tooltip", TRUE,
+#if 0
+		      "redraw-when-scrolled", TRUE,
+#endif
 		      NULL);
 	goo_canvas_set_bounds (GOO_CANVAS (canvas), 0, 0, 604, 454);
 
@@ -631,6 +636,8 @@ create_canvas_primitives (GooCanvasItemModel *model)
 	   item views to render each of the items. */
 	goo_canvas_set_root_item_model (GOO_CANVAS (canvas), model);
 
+	goo_canvas_set_static_root_item_model (GOO_CANVAS (canvas), static_model);
+
 #if 0
 	g_signal_connect_after (canvas, "key_press_event",
 				G_CALLBACK (key_press),
@@ -740,6 +747,7 @@ setup_rectangles (GooCanvasItemModel *root)
   item = goo_canvas_rect_model_new (root, 20, 30, 50, 30,
 				    "stroke-color", "red",
 				    "line-width", 8.0,
+				    "tooltip", "Red stroked rectangle",
 				    NULL);
 
   pattern = create_stipple ("mediumseagreen", stipple_data);
@@ -747,17 +755,21 @@ setup_rectangles (GooCanvasItemModel *root)
 				    "fill-pattern", pattern,
 				    "stroke-color", "black",
 				    "line-width", 4.0,
+				    "tooltip", "Medium Sea Green stippled rectangle",
 				    NULL);
   cairo_pattern_destroy (pattern);
 
   item = goo_canvas_rect_model_new (root, 10, 80, 70, 60,
 				    "fill-color", "steelblue",
+				    /*"fill-pattern", NULL,*/
+				    "tooltip", "Steel Blue rectangle",
 				    NULL);
 
   item = goo_canvas_rect_model_new (root, 20, 90, 70, 60,
 				    "fill-color-rgba", 0x3cb37180,
 				    "stroke-color", "blue",
 				    "line-width", 2.0,
+				    "tooltip", "Partially transparent rectangle",
 				    NULL);
 
   item = goo_canvas_rect_model_new (root, 110, 80, 50, 30,
@@ -765,6 +777,7 @@ setup_rectangles (GooCanvasItemModel *root)
 				    "radius-y", 10.0,
 				    "stroke-color", "yellow",
 				    "fill-color-rgba", 0x3cb3f180,
+				    "tooltip", "Rectangle with rounded corners",
 				    NULL);
 }
 
@@ -1211,6 +1224,41 @@ setup_images (GooCanvasItemModel *root)
 }
 
 
+static GooCanvasItemModel*
+create_static_model ()
+{
+  GooCanvasItemModel *static_root, *group, *item;
+
+  static_root = goo_canvas_group_model_new (NULL, NULL);
+
+  group = goo_canvas_group_model_new (static_root, NULL);
+
+  item = goo_canvas_polyline_model_new_line (group,
+					     40.0, 410.0,
+					     40.0, 330.0,
+					     "stroke-color", "midnightblue",
+					     "line-width", 3.0,
+					     "end-arrow", TRUE,
+					     "arrow-tip-length", 3.0,
+					     "arrow-length", 4.0,
+					     "arrow-width", 3.5,
+					     NULL);
+
+  item = goo_canvas_polyline_model_new_line (group,
+					     32.0, 370.0,
+					     48.0, 370.0,
+					     "stroke-color", "midnightblue",
+					     "line-width", 3.0,
+					     NULL);
+
+  item = goo_canvas_text_model_new (group, "N", 40, 320, -1, GTK_ANCHOR_S,
+				    "font", "Sans 12",
+				    NULL);
+
+  return static_root;
+}
+
+
 static void
 test_simple_transforms (GooCanvasItemModel *root)
 {
@@ -1256,6 +1304,24 @@ test_simple_transforms (GooCanvasItemModel *root)
 }
 
 
+static void
+setup_grids (GooCanvasItemModel *root)
+{
+  GooCanvasItemModel *item;
+
+  item = goo_canvas_grid_model_new (root, 80, 310, 90, 90, 10, 10, 5, 5,
+				    "stroke-color", "yellow",
+				    "fill-color", "pink",
+				    "border-width", 2.0,
+				    "border-color", "red",
+				    "vert-grid-line-color", "lightblue",
+				    "horz-grid-line-width", 1.0,
+				    "vert-grid-line-width", 1.0,
+				    "vert-grid-lines-on-top", TRUE,
+				    NULL);
+}
+
+
 static GooCanvasItemModel*
 create_model (void)
 {
@@ -1273,6 +1339,7 @@ create_model (void)
   setup_texts (root); 
   setup_images (root);
   setup_invisible_texts (root);
+  setup_grids (root);
 #endif
 #if 0
   setup_widgets (root);
@@ -1295,7 +1362,8 @@ on_delete_event (GtkWidget *window,
 
 
 static GtkWidget*
-create_window (GooCanvasItemModel *model)
+create_window (GooCanvasItemModel *model,
+	       GooCanvasItemModel *static_model)
 {
   GtkWidget *window, *notebook;
 
@@ -1310,7 +1378,7 @@ create_window (GooCanvasItemModel *model)
   gtk_container_add (GTK_CONTAINER (window), notebook);
 
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook),
-			    create_canvas_primitives (model),
+			    create_canvas_primitives (model, static_model),
 			    gtk_label_new ("Primitives"));
 #if 1
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook),
@@ -1375,21 +1443,23 @@ create_window (GooCanvasItemModel *model)
 int
 main (int argc, char *argv[])
 {
-  GooCanvasItemModel *model;
+  GooCanvasItemModel *model, *static_model;
   GtkWidget *window;
 
   gtk_set_locale ();
   gtk_init (&argc, &argv);
 
   model = create_model ();
+  static_model = create_static_model ();
 
   /* Create 2 windows to show off multiple views. */
-  window = create_window (model);
+  window = create_window (model, static_model);
 #if 1
-  window = create_window (model);
+  window = create_window (model, static_model);
 #endif
 
   g_object_unref (model);
+  g_object_unref (static_model);
 
   gtk_main ();
   return 0;
