@@ -47,6 +47,9 @@ enum {
   /* Miscellaneous signals. */
   GRAB_BROKEN_EVENT,
   CHILD_NOTIFY,
+  ANIMATION_FINISHED,
+  SCROLL_EVENT,
+  QUERY_TOOLTIP,
 
   LAST_SIGNAL
 };
@@ -117,8 +120,9 @@ goo_canvas_item_base_init (gpointer g_iface)
        * GooCanvasItem::enter-notify-event
        * @item: the item that received the signal.
        * @target_item: the target of the event.
-       * @event: the event data, with coordinates translated to canvas
-       *  coordinates.
+       * @event: the event data. The x & y fields contain the mouse position
+       *  in the item's coordinate space. The root_x & root_y fields contain
+       *  the same coordinates converted to the canvas coordinate space.
        *
        * Emitted when the mouse enters an item.
        *
@@ -141,8 +145,9 @@ goo_canvas_item_base_init (gpointer g_iface)
        * GooCanvasItem::leave-notify-event
        * @item: the item that received the signal.
        * @target_item: the target of the event.
-       * @event: the event data, with coordinates translated to canvas
-       *  coordinates.
+       * @event: the event data. The x & y fields contain the mouse position
+       *  in the item's coordinate space. The root_x & root_y fields contain
+       *  the same coordinates converted to the canvas coordinate space.
        *
        * Emitted when the mouse leaves an item.
        *
@@ -165,8 +170,9 @@ goo_canvas_item_base_init (gpointer g_iface)
        * GooCanvasItem::motion-notify-event
        * @item: the item that received the signal.
        * @target_item: the target of the event.
-       * @event: the event data, with coordinates translated to canvas
-       *  coordinates.
+       * @event: the event data. The x & y fields contain the mouse position
+       *  in the item's coordinate space. The root_x & root_y fields contain
+       *  the same coordinates converted to the canvas coordinate space.
        *
        * Emitted when the mouse moves within an item.
        *
@@ -189,8 +195,9 @@ goo_canvas_item_base_init (gpointer g_iface)
        * GooCanvasItem::button-press-event
        * @item: the item that received the signal.
        * @target_item: the target of the event.
-       * @event: the event data, with coordinates translated to canvas
-       *  coordinates.
+       * @event: the event data. The x & y fields contain the mouse position
+       *  in the item's coordinate space. The root_x & root_y fields contain
+       *  the same coordinates converted to the canvas coordinate space.
        *
        * Emitted when a mouse button is pressed in an item.
        *
@@ -213,8 +220,9 @@ goo_canvas_item_base_init (gpointer g_iface)
        * GooCanvasItem::button-release-event
        * @item: the item that received the signal.
        * @target_item: the target of the event.
-       * @event: the event data, with coordinates translated to canvas
-       *  coordinates.
+       * @event: the event data. The x & y fields contain the mouse position
+       *  in the item's coordinate space. The root_x & root_y fields contain
+       *  the same coordinates converted to the canvas coordinate space.
        *
        * Emitted when a mouse button is released in an item.
        *
@@ -330,6 +338,37 @@ goo_canvas_item_base_init (gpointer g_iface)
 		      GOO_TYPE_CANVAS_ITEM,
 		      GDK_TYPE_EVENT | G_SIGNAL_TYPE_STATIC_SCOPE);
 
+      /**
+       * GooCanvasItem::query-tooltip:
+       * @item: the item which received the signal.
+       * @x: the x coordinate of the mouse.
+       * @y: the y coordinate of the mouse.
+       * @keyboard_mode: %TRUE if the tooltip was triggered using the keyboard.
+       * @tooltip: a #GtkTooltip.
+       *
+       * Emitted when the mouse has paused over the item for a certain amount
+       * of time, or the tooltip was requested via the keyboard.
+       *
+       * Note that if @keyboard_mode is %TRUE, the values of @x and @y are
+       * undefined and should not be used.
+       *
+       * If the item wants to display a tooltip it should update @tooltip
+       * and return %TRUE.
+       *
+       * Returns: %TRUE if the item has set a tooltip to show.
+       */
+      canvas_item_signals[QUERY_TOOLTIP] =
+	g_signal_new ("query-tooltip",
+		      iface_type,
+		      G_SIGNAL_RUN_LAST,
+		      G_STRUCT_OFFSET (GooCanvasItemIface, query_tooltip),
+		      goo_canvas_boolean_handled_accumulator, NULL,
+		      goo_canvas_marshal_BOOLEAN__DOUBLE_DOUBLE_BOOLEAN_OBJECT,
+		      G_TYPE_BOOLEAN, 4,
+		      G_TYPE_DOUBLE,
+		      G_TYPE_DOUBLE,
+		      G_TYPE_BOOLEAN,
+		      GTK_TYPE_TOOLTIP);
 
       /**
        * GooCanvasItem::grab-broken-event
@@ -373,6 +412,49 @@ goo_canvas_item_base_init (gpointer g_iface)
 		      G_TYPE_NONE, 1,
 		      G_TYPE_PARAM);
 
+      /**
+       * GooCanvasItem::animation-finished
+       * @item: the item that received the signal.
+       * @stopped: if the animation was explicitly stopped.
+       *
+       * Emitted when the item animation has finished.
+       */
+      canvas_item_signals[ANIMATION_FINISHED] =
+	g_signal_new ("animation-finished",
+		      iface_type,
+		      G_SIGNAL_RUN_LAST,
+		      G_STRUCT_OFFSET (GooCanvasItemIface, animation_finished),
+		      NULL, NULL,
+		      g_cclosure_marshal_VOID__BOOLEAN,
+		      G_TYPE_NONE, 1,
+		      G_TYPE_BOOLEAN);
+
+      /**
+       * GooCanvasItem::scroll-event
+       * @item: the item that received the signal.
+       * @target_item: the target of the event.
+       * @event: the event data. The x & y fields contain the mouse position
+       *  in the item's coordinate space. The root_x & root_y fields contain
+       *  the same coordinates converted to the canvas coordinate space.
+       *
+       * Emitted when a button in the 4 to 7 range is pressed. Wheel mice are
+       * usually configured to generate button press events for buttons 4 and 5
+       * when the wheel is turned in an item.
+       *
+       * Returns: %TRUE to stop the signal emission, or %FALSE to let it
+       *  continue.
+       */
+      canvas_item_signals[SCROLL_EVENT] =
+	g_signal_new ("scroll_event",
+		      iface_type,
+		      G_SIGNAL_RUN_LAST,
+		      G_STRUCT_OFFSET (GooCanvasItemIface,
+				       scroll_event),
+		      goo_canvas_boolean_handled_accumulator, NULL,
+		      goo_canvas_marshal_BOOLEAN__OBJECT_BOXED,
+		      G_TYPE_BOOLEAN, 2,
+		      GOO_TYPE_CANVAS_ITEM,
+		      GDK_TYPE_EVENT | G_SIGNAL_TYPE_STATIC_SCOPE);
 
       g_object_interface_install_property (g_iface,
 					   g_param_spec_object ("parent",
@@ -434,6 +516,13 @@ goo_canvas_item_base_init (gpointer g_iface)
 								 FALSE,
 								 G_PARAM_READWRITE));
 
+      g_object_interface_install_property (g_iface,
+					   g_param_spec_string ("tooltip",
+								_("Tooltip"),
+								_("The tooltip to display for the item"),
+								NULL,
+								G_PARAM_READWRITE));
+
       _goo_canvas_style_init ();
 
       initialized = TRUE;
@@ -622,7 +711,8 @@ goo_canvas_item_get_n_children (GooCanvasItem       *item)
  * 
  * Gets the child item at the given stack position.
  * 
- * Returns: the child item at the given stack position.
+ * Returns: the child item at the given stack position, or %NULL if @child_num
+ * is out of range.
  **/
 GooCanvasItem*
 goo_canvas_item_get_child (GooCanvasItem       *item,
@@ -674,6 +764,49 @@ goo_canvas_item_set_parent (GooCanvasItem *item,
 }
 
 
+/**
+ * goo_canvas_item_get_is_static:
+ * @item: an item.
+ * 
+ * Returns %TRUE if the item is static. Static items do not move or change
+ * size when the canvas is scrolled or the scale changes.
+ *
+ * Returns: %TRUE if the item is static.
+ **/
+gboolean
+goo_canvas_item_get_is_static	(GooCanvasItem		*item)
+{
+  GooCanvasItemIface *iface = GOO_CANVAS_ITEM_GET_IFACE (item);
+
+  if (iface->get_is_static)
+    return iface->get_is_static (item);
+  return FALSE;
+}
+
+
+/**
+ * goo_canvas_item_set_is_static:
+ * @item: an item.
+ * @is_static: if the item is static.
+ * 
+ * Notifies the item that it is static. Static items do not move or change
+ * size when the canvas is scrolled or the scale changes.
+ *
+ * Container items such as #GooCanvasGroup should call this function when
+ * children are added, to notify children whether they are static or not.
+ * Containers should also pass on any changes in their own status to children.
+ **/
+void
+goo_canvas_item_set_is_static	(GooCanvasItem		*item,
+				 gboolean		 is_static)
+{
+  GooCanvasItemIface *iface = GOO_CANVAS_ITEM_GET_IFACE (item);
+
+  if (iface->set_is_static)
+    iface->set_is_static (item, is_static);
+}
+
+
 /**
  * goo_canvas_item_remove:
  * @item: an item.
@@ -1167,9 +1300,15 @@ goo_canvas_item_animate_cb (GooCanvasItemAnimation *anim)
 	  /* This will result in a call to goo_canvas_item_free_animation()
 	     above. We've set the timeout_id to 0 so it isn't removed twice. */
 	  if (model)
-	    g_object_set_data (G_OBJECT (model), animation_key, NULL);
+	    {
+	      g_object_set_data (G_OBJECT (model), animation_key, NULL);
+	      g_signal_emit_by_name (model, "animation-finished", FALSE);
+	    }
 	  else
-	    g_object_set_data (G_OBJECT (item), animation_key, NULL);
+	    {
+	      g_object_set_data (G_OBJECT (item), animation_key, NULL);
+	      g_signal_emit_by_name (item, "animation-finished", FALSE);
+	    }
 	  break;
 
 	case GOO_CANVAS_ANIMATE_RESTART:
@@ -1350,6 +1489,8 @@ goo_canvas_item_stop_animation (GooCanvasItem *item)
 {
   /* This will result in a call to goo_canvas_item_free_animation() above. */
   g_object_set_data (G_OBJECT (item), animation_key, NULL);
+
+  g_signal_emit_by_name (item, "animation-finished", TRUE);
 }
 
 
@@ -1553,7 +1694,7 @@ goo_canvas_item_update      (GooCanvasItem   *item,
  * goo_canvas_item_paint:
  * @item: a #GooCanvasItem.
  * @cr: a cairo context.
- * @bounds: the bounds that need to be repainted.
+ * @bounds: the bounds that need to be repainted, in device space.
  * @scale: the scale to use to determine whether an item should be painted.
  *  See #GooCanvasItem:visibility-threshold.
  * 
